import { z } from "zod";
import { IdProp } from "@simulacrum/foundation-simulator";
export declare const githubUserSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
    login: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    email: z.ZodOptional<z.ZodString>;
    organizations: z.ZodArray<z.ZodString, "many">;
}, "strip", z.ZodTypeAny, {
    login: string;
    id: string | number;
    organizations: string[];
    email?: string | undefined;
    name?: string | undefined;
}, {
    login: string;
    organizations: string[];
    id?: string | number | undefined;
    email?: string | undefined;
    name?: string | undefined;
}>, {
    login: string;
    id: string | number;
    organizations: string[];
    email?: string | undefined;
    name?: string | undefined;
}, {
    login: string;
    organizations: string[];
    id?: string | number | undefined;
    email?: string | undefined;
    name?: string | undefined;
}>;
export type GitHubUser = z.infer<typeof githubUserSchema>;
export declare const githubAppInstallationSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodOptional<z.ZodNumber>;
    account: z.ZodString;
    repository_selection: z.ZodDefault<z.ZodOptional<z.ZodEnum<["all", "selected"]>>>;
    app_id: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    access_tokens_url: z.ZodOptional<z.ZodString>;
    repositories_url: z.ZodOptional<z.ZodString>;
    html_url: z.ZodOptional<z.ZodString>;
    client_id: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    target_id: z.ZodOptional<z.ZodNumber>;
    target_type: z.ZodOptional<z.ZodEnum<["Organization", "User"]>>;
    permissions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        admin: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        push: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        pull: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    }, "strip", z.ZodTypeAny, {
        push: boolean;
        admin: boolean;
        pull: boolean;
    }, {
        push?: boolean | undefined;
        admin?: boolean | undefined;
        pull?: boolean | undefined;
    }>>>;
    events: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodAny, "many">>>;
    updated_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    created_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    single_file_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    has_multiple_single_files: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    single_file_paths: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
    app_slug: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    suspended_at: z.ZodDefault<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    suspended_by: z.ZodDefault<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    account: string;
    repository_selection: "all" | "selected";
    app_id: number;
    client_id: string;
    permissions: {
        push: boolean;
        admin: boolean;
        pull: boolean;
    };
    events: any[];
    updated_at: string;
    created_at: string;
    single_file_name: string;
    has_multiple_single_files: boolean;
    single_file_paths: string[];
    app_slug: string;
    suspended_at: string | null;
    suspended_by: string | null;
    id?: number | undefined;
    access_tokens_url?: string | undefined;
    repositories_url?: string | undefined;
    html_url?: string | undefined;
    target_id?: number | undefined;
    target_type?: "Organization" | "User" | undefined;
}, {
    account: string;
    id?: number | undefined;
    repository_selection?: "all" | "selected" | undefined;
    app_id?: number | undefined;
    access_tokens_url?: string | undefined;
    repositories_url?: string | undefined;
    html_url?: string | undefined;
    client_id?: string | undefined;
    target_id?: number | undefined;
    target_type?: "Organization" | "User" | undefined;
    permissions?: {
        push?: boolean | undefined;
        admin?: boolean | undefined;
        pull?: boolean | undefined;
    } | undefined;
    events?: any[] | undefined;
    updated_at?: string | undefined;
    created_at?: string | undefined;
    single_file_name?: string | undefined;
    has_multiple_single_files?: boolean | undefined;
    single_file_paths?: string[] | undefined;
    app_slug?: string | undefined;
    suspended_at?: string | null | undefined;
    suspended_by?: string | null | undefined;
}>, {
    account: string;
    repository_selection: "all" | "selected";
    app_id: number;
    client_id: string;
    permissions: {
        push: boolean;
        admin: boolean;
        pull: boolean;
    };
    events: any[];
    updated_at: string;
    created_at: string;
    single_file_name: string;
    has_multiple_single_files: boolean;
    single_file_paths: string[];
    app_slug: string;
    suspended_at: string | null;
    suspended_by: string | null;
    id?: number | undefined;
    access_tokens_url?: string | undefined;
    repositories_url?: string | undefined;
    html_url?: string | undefined;
    target_id?: number | undefined;
    target_type?: "Organization" | "User" | undefined;
}, {
    account: string;
    id?: number | undefined;
    repository_selection?: "all" | "selected" | undefined;
    app_id?: number | undefined;
    access_tokens_url?: string | undefined;
    repositories_url?: string | undefined;
    html_url?: string | undefined;
    client_id?: string | undefined;
    target_id?: number | undefined;
    target_type?: "Organization" | "User" | undefined;
    permissions?: {
        push?: boolean | undefined;
        admin?: boolean | undefined;
        pull?: boolean | undefined;
    } | undefined;
    events?: any[] | undefined;
    updated_at?: string | undefined;
    created_at?: string | undefined;
    single_file_name?: string | undefined;
    has_multiple_single_files?: boolean | undefined;
    single_file_paths?: string[] | undefined;
    app_slug?: string | undefined;
    suspended_at?: string | null | undefined;
    suspended_by?: string | null | undefined;
}>;
export type GitHubAppInstallation = z.infer<typeof githubAppInstallationSchema>;
export declare const githubRepositorySchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodOptional<z.ZodNumber>;
    node_id: z.ZodOptional<z.ZodString>;
    name: z.ZodString;
    description: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    owner: z.ZodString;
    full_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    packages: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    pushed_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    updated_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    created_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    url: z.ZodOptional<z.ZodString>;
    html_url: z.ZodOptional<z.ZodString>;
    archive_url: z.ZodOptional<z.ZodString>;
    assignees_url: z.ZodOptional<z.ZodString>;
    blobs_url: z.ZodOptional<z.ZodString>;
    branches_url: z.ZodOptional<z.ZodString>;
    collaborators_url: z.ZodOptional<z.ZodString>;
    comments_url: z.ZodOptional<z.ZodString>;
    commits_url: z.ZodOptional<z.ZodString>;
    compare_url: z.ZodOptional<z.ZodString>;
    contents_url: z.ZodOptional<z.ZodString>;
    contributors_url: z.ZodOptional<z.ZodString>;
    deployments_url: z.ZodOptional<z.ZodString>;
    downloads_url: z.ZodOptional<z.ZodString>;
    events_url: z.ZodOptional<z.ZodString>;
    forks_url: z.ZodOptional<z.ZodString>;
    git_commits_url: z.ZodOptional<z.ZodString>;
    git_refs_url: z.ZodOptional<z.ZodString>;
    git_tags_url: z.ZodOptional<z.ZodString>;
    git_url: z.ZodOptional<z.ZodString>;
    issue_comment_url: z.ZodOptional<z.ZodString>;
    issue_events_url: z.ZodOptional<z.ZodString>;
    issues_url: z.ZodOptional<z.ZodString>;
    keys_url: z.ZodOptional<z.ZodString>;
    labels_url: z.ZodOptional<z.ZodString>;
    languages_url: z.ZodOptional<z.ZodString>;
    merges_url: z.ZodOptional<z.ZodString>;
    milestones_url: z.ZodOptional<z.ZodString>;
    notifications_url: z.ZodOptional<z.ZodString>;
    pulls_url: z.ZodOptional<z.ZodString>;
    releases_url: z.ZodOptional<z.ZodString>;
    ssh_url: z.ZodOptional<z.ZodString>;
    stargazers_url: z.ZodOptional<z.ZodString>;
    statuses_url: z.ZodOptional<z.ZodString>;
    subscribers_url: z.ZodOptional<z.ZodString>;
    subscription_url: z.ZodOptional<z.ZodString>;
    tags_url: z.ZodOptional<z.ZodString>;
    teams_url: z.ZodOptional<z.ZodString>;
    trees_url: z.ZodOptional<z.ZodString>;
    clone_url: z.ZodOptional<z.ZodString>;
    mirror_url: z.ZodOptional<z.ZodString>;
    hooks_url: z.ZodOptional<z.ZodString>;
    svn_url: z.ZodOptional<z.ZodString>;
    homepage: z.ZodOptional<z.ZodString>;
    language: z.ZodDefault<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    default_branch: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    visibility: z.ZodDefault<z.ZodEnum<["public", "private"]>>;
    private: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    license: z.ZodDefault<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
    fork: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    topics: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
    is_template: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    has_issues: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    has_projects: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    has_wiki: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    has_pages: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    has_downloads: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    has_discussions: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    archived: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    disabled: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    forks_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    forks: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    stargazers_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    stargazers: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    watchers_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    watchers: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    size: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    open_issues_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    open_issues: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
    permissions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        admin: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        push: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        pull: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    }, "strip", z.ZodTypeAny, {
        push: boolean;
        admin: boolean;
        pull: boolean;
    }, {
        push?: boolean | undefined;
        admin?: boolean | undefined;
        pull?: boolean | undefined;
    }>>>;
    security_and_analysis: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        advanced_security: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            status: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            status: string;
        }, {
            status: string;
        }>>>;
        secret_scanning: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            status: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            status: string;
        }, {
            status: string;
        }>>>;
        secret_scanning_push_protection: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            status: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            status: string;
        }, {
            status: string;
        }>>>;
        secret_scanning_non_provider_patterns: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            status: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            status: string;
        }, {
            status: string;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        advanced_security: {
            status: string;
        };
        secret_scanning: {
            status: string;
        };
        secret_scanning_push_protection: {
            status: string;
        };
        secret_scanning_non_provider_patterns: {
            status: string;
        };
    }, {
        advanced_security?: {
            status: string;
        } | undefined;
        secret_scanning?: {
            status: string;
        } | undefined;
        secret_scanning_push_protection?: {
            status: string;
        } | undefined;
        secret_scanning_non_provider_patterns?: {
            status: string;
        } | undefined;
    }>>>;
}, "strip", z.ZodTypeAny, {
    name: string;
    description: string;
    visibility: "public" | "private";
    forks: number;
    owner: string;
    watchers: number;
    stargazers: number;
    size: number;
    permissions: {
        push: boolean;
        admin: boolean;
        pull: boolean;
    };
    updated_at: string;
    created_at: string;
    full_name: string;
    pushed_at: string;
    language: string | null;
    default_branch: string;
    private: boolean;
    license: Record<string, string> | null;
    fork: boolean;
    topics: string[];
    is_template: boolean;
    has_issues: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    has_pages: boolean;
    has_downloads: boolean;
    has_discussions: boolean;
    archived: boolean;
    disabled: boolean;
    forks_count: number;
    stargazers_count: number;
    watchers_count: number;
    open_issues_count: number;
    open_issues: number;
    security_and_analysis: {
        advanced_security: {
            status: string;
        };
        secret_scanning: {
            status: string;
        };
        secret_scanning_push_protection: {
            status: string;
        };
        secret_scanning_non_provider_patterns: {
            status: string;
        };
    };
    url?: string | undefined;
    id?: number | undefined;
    packages?: string[] | undefined;
    html_url?: string | undefined;
    node_id?: string | undefined;
    archive_url?: string | undefined;
    assignees_url?: string | undefined;
    blobs_url?: string | undefined;
    branches_url?: string | undefined;
    collaborators_url?: string | undefined;
    comments_url?: string | undefined;
    commits_url?: string | undefined;
    compare_url?: string | undefined;
    contents_url?: string | undefined;
    contributors_url?: string | undefined;
    deployments_url?: string | undefined;
    downloads_url?: string | undefined;
    events_url?: string | undefined;
    forks_url?: string | undefined;
    git_commits_url?: string | undefined;
    git_refs_url?: string | undefined;
    git_tags_url?: string | undefined;
    git_url?: string | undefined;
    issue_comment_url?: string | undefined;
    issue_events_url?: string | undefined;
    issues_url?: string | undefined;
    keys_url?: string | undefined;
    labels_url?: string | undefined;
    languages_url?: string | undefined;
    merges_url?: string | undefined;
    milestones_url?: string | undefined;
    notifications_url?: string | undefined;
    pulls_url?: string | undefined;
    releases_url?: string | undefined;
    ssh_url?: string | undefined;
    stargazers_url?: string | undefined;
    statuses_url?: string | undefined;
    subscribers_url?: string | undefined;
    subscription_url?: string | undefined;
    tags_url?: string | undefined;
    teams_url?: string | undefined;
    trees_url?: string | undefined;
    clone_url?: string | undefined;
    mirror_url?: string | undefined;
    hooks_url?: string | undefined;
    svn_url?: string | undefined;
    homepage?: string | undefined;
}, {
    name: string;
    owner: string;
    url?: string | undefined;
    id?: number | undefined;
    packages?: string[] | undefined;
    description?: string | undefined;
    visibility?: "public" | "private" | undefined;
    forks?: number | undefined;
    watchers?: number | undefined;
    stargazers?: number | undefined;
    size?: number | undefined;
    html_url?: string | undefined;
    permissions?: {
        push?: boolean | undefined;
        admin?: boolean | undefined;
        pull?: boolean | undefined;
    } | undefined;
    updated_at?: string | undefined;
    created_at?: string | undefined;
    node_id?: string | undefined;
    full_name?: string | undefined;
    pushed_at?: string | undefined;
    archive_url?: string | undefined;
    assignees_url?: string | undefined;
    blobs_url?: string | undefined;
    branches_url?: string | undefined;
    collaborators_url?: string | undefined;
    comments_url?: string | undefined;
    commits_url?: string | undefined;
    compare_url?: string | undefined;
    contents_url?: string | undefined;
    contributors_url?: string | undefined;
    deployments_url?: string | undefined;
    downloads_url?: string | undefined;
    events_url?: string | undefined;
    forks_url?: string | undefined;
    git_commits_url?: string | undefined;
    git_refs_url?: string | undefined;
    git_tags_url?: string | undefined;
    git_url?: string | undefined;
    issue_comment_url?: string | undefined;
    issue_events_url?: string | undefined;
    issues_url?: string | undefined;
    keys_url?: string | undefined;
    labels_url?: string | undefined;
    languages_url?: string | undefined;
    merges_url?: string | undefined;
    milestones_url?: string | undefined;
    notifications_url?: string | undefined;
    pulls_url?: string | undefined;
    releases_url?: string | undefined;
    ssh_url?: string | undefined;
    stargazers_url?: string | undefined;
    statuses_url?: string | undefined;
    subscribers_url?: string | undefined;
    subscription_url?: string | undefined;
    tags_url?: string | undefined;
    teams_url?: string | undefined;
    trees_url?: string | undefined;
    clone_url?: string | undefined;
    mirror_url?: string | undefined;
    hooks_url?: string | undefined;
    svn_url?: string | undefined;
    homepage?: string | undefined;
    language?: string | null | undefined;
    default_branch?: string | undefined;
    private?: boolean | undefined;
    license?: Record<string, string> | null | undefined;
    fork?: boolean | undefined;
    topics?: string[] | undefined;
    is_template?: boolean | undefined;
    has_issues?: boolean | undefined;
    has_projects?: boolean | undefined;
    has_wiki?: boolean | undefined;
    has_pages?: boolean | undefined;
    has_downloads?: boolean | undefined;
    has_discussions?: boolean | undefined;
    archived?: boolean | undefined;
    disabled?: boolean | undefined;
    forks_count?: number | undefined;
    stargazers_count?: number | undefined;
    watchers_count?: number | undefined;
    open_issues_count?: number | undefined;
    open_issues?: number | undefined;
    security_and_analysis?: {
        advanced_security?: {
            status: string;
        } | undefined;
        secret_scanning?: {
            status: string;
        } | undefined;
        secret_scanning_push_protection?: {
            status: string;
        } | undefined;
        secret_scanning_non_provider_patterns?: {
            status: string;
        } | undefined;
    } | undefined;
}>, {
    name: string;
    description: string;
    visibility: "public" | "private";
    forks: number;
    owner: string;
    watchers: number;
    stargazers: number;
    size: number;
    permissions: {
        push: boolean;
        admin: boolean;
        pull: boolean;
    };
    updated_at: string;
    created_at: string;
    full_name: string;
    pushed_at: string;
    language: string | null;
    default_branch: string;
    private: boolean;
    license: Record<string, string> | null;
    fork: boolean;
    topics: string[];
    is_template: boolean;
    has_issues: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    has_pages: boolean;
    has_downloads: boolean;
    has_discussions: boolean;
    archived: boolean;
    disabled: boolean;
    forks_count: number;
    stargazers_count: number;
    watchers_count: number;
    open_issues_count: number;
    open_issues: number;
    security_and_analysis: {
        advanced_security: {
            status: string;
        };
        secret_scanning: {
            status: string;
        };
        secret_scanning_push_protection: {
            status: string;
        };
        secret_scanning_non_provider_patterns: {
            status: string;
        };
    };
    url?: string | undefined;
    id?: number | undefined;
    packages?: string[] | undefined;
    html_url?: string | undefined;
    node_id?: string | undefined;
    archive_url?: string | undefined;
    assignees_url?: string | undefined;
    blobs_url?: string | undefined;
    branches_url?: string | undefined;
    collaborators_url?: string | undefined;
    comments_url?: string | undefined;
    commits_url?: string | undefined;
    compare_url?: string | undefined;
    contents_url?: string | undefined;
    contributors_url?: string | undefined;
    deployments_url?: string | undefined;
    downloads_url?: string | undefined;
    events_url?: string | undefined;
    forks_url?: string | undefined;
    git_commits_url?: string | undefined;
    git_refs_url?: string | undefined;
    git_tags_url?: string | undefined;
    git_url?: string | undefined;
    issue_comment_url?: string | undefined;
    issue_events_url?: string | undefined;
    issues_url?: string | undefined;
    keys_url?: string | undefined;
    labels_url?: string | undefined;
    languages_url?: string | undefined;
    merges_url?: string | undefined;
    milestones_url?: string | undefined;
    notifications_url?: string | undefined;
    pulls_url?: string | undefined;
    releases_url?: string | undefined;
    ssh_url?: string | undefined;
    stargazers_url?: string | undefined;
    statuses_url?: string | undefined;
    subscribers_url?: string | undefined;
    subscription_url?: string | undefined;
    tags_url?: string | undefined;
    teams_url?: string | undefined;
    trees_url?: string | undefined;
    clone_url?: string | undefined;
    mirror_url?: string | undefined;
    hooks_url?: string | undefined;
    svn_url?: string | undefined;
    homepage?: string | undefined;
}, {
    name: string;
    owner: string;
    url?: string | undefined;
    id?: number | undefined;
    packages?: string[] | undefined;
    description?: string | undefined;
    visibility?: "public" | "private" | undefined;
    forks?: number | undefined;
    watchers?: number | undefined;
    stargazers?: number | undefined;
    size?: number | undefined;
    html_url?: string | undefined;
    permissions?: {
        push?: boolean | undefined;
        admin?: boolean | undefined;
        pull?: boolean | undefined;
    } | undefined;
    updated_at?: string | undefined;
    created_at?: string | undefined;
    node_id?: string | undefined;
    full_name?: string | undefined;
    pushed_at?: string | undefined;
    archive_url?: string | undefined;
    assignees_url?: string | undefined;
    blobs_url?: string | undefined;
    branches_url?: string | undefined;
    collaborators_url?: string | undefined;
    comments_url?: string | undefined;
    commits_url?: string | undefined;
    compare_url?: string | undefined;
    contents_url?: string | undefined;
    contributors_url?: string | undefined;
    deployments_url?: string | undefined;
    downloads_url?: string | undefined;
    events_url?: string | undefined;
    forks_url?: string | undefined;
    git_commits_url?: string | undefined;
    git_refs_url?: string | undefined;
    git_tags_url?: string | undefined;
    git_url?: string | undefined;
    issue_comment_url?: string | undefined;
    issue_events_url?: string | undefined;
    issues_url?: string | undefined;
    keys_url?: string | undefined;
    labels_url?: string | undefined;
    languages_url?: string | undefined;
    merges_url?: string | undefined;
    milestones_url?: string | undefined;
    notifications_url?: string | undefined;
    pulls_url?: string | undefined;
    releases_url?: string | undefined;
    ssh_url?: string | undefined;
    stargazers_url?: string | undefined;
    statuses_url?: string | undefined;
    subscribers_url?: string | undefined;
    subscription_url?: string | undefined;
    tags_url?: string | undefined;
    teams_url?: string | undefined;
    trees_url?: string | undefined;
    clone_url?: string | undefined;
    mirror_url?: string | undefined;
    hooks_url?: string | undefined;
    svn_url?: string | undefined;
    homepage?: string | undefined;
    language?: string | null | undefined;
    default_branch?: string | undefined;
    private?: boolean | undefined;
    license?: Record<string, string> | null | undefined;
    fork?: boolean | undefined;
    topics?: string[] | undefined;
    is_template?: boolean | undefined;
    has_issues?: boolean | undefined;
    has_projects?: boolean | undefined;
    has_wiki?: boolean | undefined;
    has_pages?: boolean | undefined;
    has_downloads?: boolean | undefined;
    has_discussions?: boolean | undefined;
    archived?: boolean | undefined;
    disabled?: boolean | undefined;
    forks_count?: number | undefined;
    stargazers_count?: number | undefined;
    watchers_count?: number | undefined;
    open_issues_count?: number | undefined;
    open_issues?: number | undefined;
    security_and_analysis?: {
        advanced_security?: {
            status: string;
        } | undefined;
        secret_scanning?: {
            status: string;
        } | undefined;
        secret_scanning_push_protection?: {
            status: string;
        } | undefined;
        secret_scanning_non_provider_patterns?: {
            status: string;
        } | undefined;
    } | undefined;
}>;
export type GitHubRepository = z.infer<typeof githubRepositorySchema>;
export declare const githubBranchSchema: z.ZodObject<{
    name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    commit: z.ZodDefault<z.ZodObject<{
        sha: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        url?: string | undefined;
        sha?: string | undefined;
    }, {
        url?: string | undefined;
        sha?: string | undefined;
    }>>;
    protected: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    protection: z.ZodOptional<z.ZodAny>;
    protection_url: z.ZodDefault<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    name: string;
    commit: {
        url?: string | undefined;
        sha?: string | undefined;
    };
    protected: boolean;
    protection_url: string;
    protection?: any;
}, {
    name?: string | undefined;
    commit?: {
        url?: string | undefined;
        sha?: string | undefined;
    } | undefined;
    protected?: boolean | undefined;
    protection?: any;
    protection_url?: string | undefined;
}>;
export type GitHubBranch = z.infer<typeof githubBranchSchema>;
export declare const githubOrganizationSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodOptional<z.ZodNumber>;
    login: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    email: z.ZodOptional<z.ZodString>;
    node_id: z.ZodOptional<z.ZodString>;
    type: z.ZodDefault<z.ZodEnum<["User", "Organization"]>>;
    description: z.ZodOptional<z.ZodString>;
    created_at: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    teams: z.ZodUnion<[z.ZodArray<z.ZodString, "many">, z.ZodUndefined]>;
    avatar_url: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    gravatar_id: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    site_admin: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    url: z.ZodOptional<z.ZodString>;
    html_url: z.ZodOptional<z.ZodString>;
    followers_url: z.ZodOptional<z.ZodString>;
    following_url: z.ZodOptional<z.ZodString>;
    gists_url: z.ZodOptional<z.ZodString>;
    starred_url: z.ZodOptional<z.ZodString>;
    subscriptions_url: z.ZodOptional<z.ZodString>;
    organizations_url: z.ZodOptional<z.ZodString>;
    repos_url: z.ZodOptional<z.ZodString>;
    events_url: z.ZodOptional<z.ZodString>;
    received_events_url: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    login: string;
    type: "Organization" | "User";
    avatar_url: string;
    gravatar_id: string;
    site_admin: boolean;
    url?: string | undefined;
    id?: number | undefined;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    html_url?: string | undefined;
    created_at?: string | undefined;
    node_id?: string | undefined;
    events_url?: string | undefined;
    followers_url?: string | undefined;
    following_url?: string | undefined;
    gists_url?: string | undefined;
    starred_url?: string | undefined;
    subscriptions_url?: string | undefined;
    organizations_url?: string | undefined;
    repos_url?: string | undefined;
    received_events_url?: string | undefined;
}, {
    login: string;
    url?: string | undefined;
    id?: number | undefined;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    type?: "Organization" | "User" | undefined;
    html_url?: string | undefined;
    created_at?: string | undefined;
    node_id?: string | undefined;
    events_url?: string | undefined;
    avatar_url?: string | undefined;
    gravatar_id?: string | undefined;
    site_admin?: boolean | undefined;
    followers_url?: string | undefined;
    following_url?: string | undefined;
    gists_url?: string | undefined;
    starred_url?: string | undefined;
    subscriptions_url?: string | undefined;
    organizations_url?: string | undefined;
    repos_url?: string | undefined;
    received_events_url?: string | undefined;
}>, {
    login: string;
    type: "Organization" | "User";
    avatar_url: string;
    gravatar_id: string;
    site_admin: boolean;
    url?: string | undefined;
    id?: number | undefined;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    html_url?: string | undefined;
    created_at?: string | undefined;
    node_id?: string | undefined;
    events_url?: string | undefined;
    followers_url?: string | undefined;
    following_url?: string | undefined;
    gists_url?: string | undefined;
    starred_url?: string | undefined;
    subscriptions_url?: string | undefined;
    organizations_url?: string | undefined;
    repos_url?: string | undefined;
    received_events_url?: string | undefined;
}, {
    login: string;
    url?: string | undefined;
    id?: number | undefined;
    email?: string | undefined;
    name?: string | undefined;
    description?: string | undefined;
    teams?: string[] | undefined;
    type?: "Organization" | "User" | undefined;
    html_url?: string | undefined;
    created_at?: string | undefined;
    node_id?: string | undefined;
    events_url?: string | undefined;
    avatar_url?: string | undefined;
    gravatar_id?: string | undefined;
    site_admin?: boolean | undefined;
    followers_url?: string | undefined;
    following_url?: string | undefined;
    gists_url?: string | undefined;
    starred_url?: string | undefined;
    subscriptions_url?: string | undefined;
    organizations_url?: string | undefined;
    repos_url?: string | undefined;
    received_events_url?: string | undefined;
}>;
export type GitHubOrganization = z.infer<typeof githubOrganizationSchema>;
export declare const githubBlobSchema: z.ZodEffects<z.ZodObject<{
    id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
    content: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    encoding: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"string">, z.ZodLiteral<"base64">]>>;
    owner: z.ZodString;
    repo: z.ZodString;
    path: z.ZodString;
    sha: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string | number;
    owner: string;
    path: string;
    content: string;
    sha: string;
    encoding: "string" | "base64";
    repo: string;
}, {
    owner: string;
    path: string;
    sha: string;
    repo: string;
    id?: string | number | undefined;
    content?: string | undefined;
    encoding?: "string" | "base64" | undefined;
}>, {
    id: string | number;
    owner: string;
    path: string;
    content: string;
    sha: string;
    encoding: "string" | "base64";
    repo: string;
}, {
    owner: string;
    path: string;
    sha: string;
    repo: string;
    id?: string | number | undefined;
    content?: string | undefined;
    encoding?: "string" | "base64" | undefined;
}>;
export type GitHubBlob = z.infer<typeof githubBlobSchema>;
export declare const gitubInitialStoreSchema: z.ZodEffects<z.ZodObject<{
    users: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
        login: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        email: z.ZodOptional<z.ZodString>;
        organizations: z.ZodArray<z.ZodString, "many">;
    }, "strip", z.ZodTypeAny, {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }, {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }>, {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }, {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }>, "many">;
    installations: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodOptional<z.ZodNumber>;
        account: z.ZodString;
        repository_selection: z.ZodDefault<z.ZodOptional<z.ZodEnum<["all", "selected"]>>>;
        app_id: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        access_tokens_url: z.ZodOptional<z.ZodString>;
        repositories_url: z.ZodOptional<z.ZodString>;
        html_url: z.ZodOptional<z.ZodString>;
        client_id: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        target_id: z.ZodOptional<z.ZodNumber>;
        target_type: z.ZodOptional<z.ZodEnum<["Organization", "User"]>>;
        permissions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            admin: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            push: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            pull: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            push: boolean;
            admin: boolean;
            pull: boolean;
        }, {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        }>>>;
        events: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodAny, "many">>>;
        updated_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        created_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        single_file_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        has_multiple_single_files: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        single_file_paths: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
        app_slug: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        suspended_at: z.ZodDefault<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
        suspended_by: z.ZodDefault<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        account: string;
        repository_selection: "all" | "selected";
        app_id: number;
        client_id: string;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        events: any[];
        updated_at: string;
        created_at: string;
        single_file_name: string;
        has_multiple_single_files: boolean;
        single_file_paths: string[];
        app_slug: string;
        suspended_at: string | null;
        suspended_by: string | null;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
    }, {
        account: string;
        id?: number | undefined;
        repository_selection?: "all" | "selected" | undefined;
        app_id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        client_id?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        events?: any[] | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        single_file_name?: string | undefined;
        has_multiple_single_files?: boolean | undefined;
        single_file_paths?: string[] | undefined;
        app_slug?: string | undefined;
        suspended_at?: string | null | undefined;
        suspended_by?: string | null | undefined;
    }>, {
        account: string;
        repository_selection: "all" | "selected";
        app_id: number;
        client_id: string;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        events: any[];
        updated_at: string;
        created_at: string;
        single_file_name: string;
        has_multiple_single_files: boolean;
        single_file_paths: string[];
        app_slug: string;
        suspended_at: string | null;
        suspended_by: string | null;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
    }, {
        account: string;
        id?: number | undefined;
        repository_selection?: "all" | "selected" | undefined;
        app_id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        client_id?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        events?: any[] | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        single_file_name?: string | undefined;
        has_multiple_single_files?: boolean | undefined;
        single_file_paths?: string[] | undefined;
        app_slug?: string | undefined;
        suspended_at?: string | null | undefined;
        suspended_by?: string | null | undefined;
    }>, "many">>>;
    organizations: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodOptional<z.ZodNumber>;
        login: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        email: z.ZodOptional<z.ZodString>;
        node_id: z.ZodOptional<z.ZodString>;
        type: z.ZodDefault<z.ZodEnum<["User", "Organization"]>>;
        description: z.ZodOptional<z.ZodString>;
        created_at: z.ZodOptional<z.ZodDefault<z.ZodString>>;
        teams: z.ZodUnion<[z.ZodArray<z.ZodString, "many">, z.ZodUndefined]>;
        avatar_url: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        gravatar_id: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        site_admin: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        url: z.ZodOptional<z.ZodString>;
        html_url: z.ZodOptional<z.ZodString>;
        followers_url: z.ZodOptional<z.ZodString>;
        following_url: z.ZodOptional<z.ZodString>;
        gists_url: z.ZodOptional<z.ZodString>;
        starred_url: z.ZodOptional<z.ZodString>;
        subscriptions_url: z.ZodOptional<z.ZodString>;
        organizations_url: z.ZodOptional<z.ZodString>;
        repos_url: z.ZodOptional<z.ZodString>;
        events_url: z.ZodOptional<z.ZodString>;
        received_events_url: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }, {
        login: string;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        type?: "Organization" | "User" | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        avatar_url?: string | undefined;
        gravatar_id?: string | undefined;
        site_admin?: boolean | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }>, {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }, {
        login: string;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        type?: "Organization" | "User" | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        avatar_url?: string | undefined;
        gravatar_id?: string | undefined;
        site_admin?: boolean | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }>, "many">;
    repositories: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodOptional<z.ZodNumber>;
        node_id: z.ZodOptional<z.ZodString>;
        name: z.ZodString;
        description: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        owner: z.ZodString;
        full_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        packages: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        pushed_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        updated_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        created_at: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        url: z.ZodOptional<z.ZodString>;
        html_url: z.ZodOptional<z.ZodString>;
        archive_url: z.ZodOptional<z.ZodString>;
        assignees_url: z.ZodOptional<z.ZodString>;
        blobs_url: z.ZodOptional<z.ZodString>;
        branches_url: z.ZodOptional<z.ZodString>;
        collaborators_url: z.ZodOptional<z.ZodString>;
        comments_url: z.ZodOptional<z.ZodString>;
        commits_url: z.ZodOptional<z.ZodString>;
        compare_url: z.ZodOptional<z.ZodString>;
        contents_url: z.ZodOptional<z.ZodString>;
        contributors_url: z.ZodOptional<z.ZodString>;
        deployments_url: z.ZodOptional<z.ZodString>;
        downloads_url: z.ZodOptional<z.ZodString>;
        events_url: z.ZodOptional<z.ZodString>;
        forks_url: z.ZodOptional<z.ZodString>;
        git_commits_url: z.ZodOptional<z.ZodString>;
        git_refs_url: z.ZodOptional<z.ZodString>;
        git_tags_url: z.ZodOptional<z.ZodString>;
        git_url: z.ZodOptional<z.ZodString>;
        issue_comment_url: z.ZodOptional<z.ZodString>;
        issue_events_url: z.ZodOptional<z.ZodString>;
        issues_url: z.ZodOptional<z.ZodString>;
        keys_url: z.ZodOptional<z.ZodString>;
        labels_url: z.ZodOptional<z.ZodString>;
        languages_url: z.ZodOptional<z.ZodString>;
        merges_url: z.ZodOptional<z.ZodString>;
        milestones_url: z.ZodOptional<z.ZodString>;
        notifications_url: z.ZodOptional<z.ZodString>;
        pulls_url: z.ZodOptional<z.ZodString>;
        releases_url: z.ZodOptional<z.ZodString>;
        ssh_url: z.ZodOptional<z.ZodString>;
        stargazers_url: z.ZodOptional<z.ZodString>;
        statuses_url: z.ZodOptional<z.ZodString>;
        subscribers_url: z.ZodOptional<z.ZodString>;
        subscription_url: z.ZodOptional<z.ZodString>;
        tags_url: z.ZodOptional<z.ZodString>;
        teams_url: z.ZodOptional<z.ZodString>;
        trees_url: z.ZodOptional<z.ZodString>;
        clone_url: z.ZodOptional<z.ZodString>;
        mirror_url: z.ZodOptional<z.ZodString>;
        hooks_url: z.ZodOptional<z.ZodString>;
        svn_url: z.ZodOptional<z.ZodString>;
        homepage: z.ZodOptional<z.ZodString>;
        language: z.ZodDefault<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
        default_branch: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        visibility: z.ZodDefault<z.ZodEnum<["public", "private"]>>;
        private: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        license: z.ZodDefault<z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodString>>>;
        fork: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        topics: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
        is_template: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        has_issues: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        has_projects: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        has_wiki: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        has_pages: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        has_downloads: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        has_discussions: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        archived: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        disabled: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        forks_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        forks: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        stargazers_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        stargazers: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        watchers_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        watchers: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        size: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        open_issues_count: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        open_issues: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        permissions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            admin: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            push: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            pull: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            push: boolean;
            admin: boolean;
            pull: boolean;
        }, {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        }>>>;
        security_and_analysis: z.ZodDefault<z.ZodOptional<z.ZodObject<{
            advanced_security: z.ZodDefault<z.ZodOptional<z.ZodObject<{
                status: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                status: string;
            }, {
                status: string;
            }>>>;
            secret_scanning: z.ZodDefault<z.ZodOptional<z.ZodObject<{
                status: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                status: string;
            }, {
                status: string;
            }>>>;
            secret_scanning_push_protection: z.ZodDefault<z.ZodOptional<z.ZodObject<{
                status: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                status: string;
            }, {
                status: string;
            }>>>;
            secret_scanning_non_provider_patterns: z.ZodDefault<z.ZodOptional<z.ZodObject<{
                status: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                status: string;
            }, {
                status: string;
            }>>>;
        }, "strip", z.ZodTypeAny, {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        }, {
            advanced_security?: {
                status: string;
            } | undefined;
            secret_scanning?: {
                status: string;
            } | undefined;
            secret_scanning_push_protection?: {
                status: string;
            } | undefined;
            secret_scanning_non_provider_patterns?: {
                status: string;
            } | undefined;
        }>>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        owner: string;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }, {
        name: string;
        owner: string;
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        description?: string | undefined;
        visibility?: "public" | "private" | undefined;
        forks?: number | undefined;
        watchers?: number | undefined;
        stargazers?: number | undefined;
        size?: number | undefined;
        html_url?: string | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        full_name?: string | undefined;
        pushed_at?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
        language?: string | null | undefined;
        default_branch?: string | undefined;
        private?: boolean | undefined;
        license?: Record<string, string> | null | undefined;
        fork?: boolean | undefined;
        topics?: string[] | undefined;
        is_template?: boolean | undefined;
        has_issues?: boolean | undefined;
        has_projects?: boolean | undefined;
        has_wiki?: boolean | undefined;
        has_pages?: boolean | undefined;
        has_downloads?: boolean | undefined;
        has_discussions?: boolean | undefined;
        archived?: boolean | undefined;
        disabled?: boolean | undefined;
        forks_count?: number | undefined;
        stargazers_count?: number | undefined;
        watchers_count?: number | undefined;
        open_issues_count?: number | undefined;
        open_issues?: number | undefined;
        security_and_analysis?: {
            advanced_security?: {
                status: string;
            } | undefined;
            secret_scanning?: {
                status: string;
            } | undefined;
            secret_scanning_push_protection?: {
                status: string;
            } | undefined;
            secret_scanning_non_provider_patterns?: {
                status: string;
            } | undefined;
        } | undefined;
    }>, {
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        owner: string;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }, {
        name: string;
        owner: string;
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        description?: string | undefined;
        visibility?: "public" | "private" | undefined;
        forks?: number | undefined;
        watchers?: number | undefined;
        stargazers?: number | undefined;
        size?: number | undefined;
        html_url?: string | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        full_name?: string | undefined;
        pushed_at?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
        language?: string | null | undefined;
        default_branch?: string | undefined;
        private?: boolean | undefined;
        license?: Record<string, string> | null | undefined;
        fork?: boolean | undefined;
        topics?: string[] | undefined;
        is_template?: boolean | undefined;
        has_issues?: boolean | undefined;
        has_projects?: boolean | undefined;
        has_wiki?: boolean | undefined;
        has_pages?: boolean | undefined;
        has_downloads?: boolean | undefined;
        has_discussions?: boolean | undefined;
        archived?: boolean | undefined;
        disabled?: boolean | undefined;
        forks_count?: number | undefined;
        stargazers_count?: number | undefined;
        watchers_count?: number | undefined;
        open_issues_count?: number | undefined;
        open_issues?: number | undefined;
        security_and_analysis?: {
            advanced_security?: {
                status: string;
            } | undefined;
            secret_scanning?: {
                status: string;
            } | undefined;
            secret_scanning_push_protection?: {
                status: string;
            } | undefined;
            secret_scanning_non_provider_patterns?: {
                status: string;
            } | undefined;
        } | undefined;
    }>, "many">;
    branches: z.ZodArray<z.ZodObject<{
        name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        commit: z.ZodDefault<z.ZodObject<{
            sha: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            url?: string | undefined;
            sha?: string | undefined;
        }, {
            url?: string | undefined;
            sha?: string | undefined;
        }>>;
        protected: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        protection: z.ZodOptional<z.ZodAny>;
        protection_url: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        commit: {
            url?: string | undefined;
            sha?: string | undefined;
        };
        protected: boolean;
        protection_url: string;
        protection?: any;
    }, {
        name?: string | undefined;
        commit?: {
            url?: string | undefined;
            sha?: string | undefined;
        } | undefined;
        protected?: boolean | undefined;
        protection?: any;
        protection_url?: string | undefined;
    }>, "many">;
    blobs: z.ZodArray<z.ZodEffects<z.ZodObject<{
        id: z.ZodDefault<z.ZodUnion<[z.ZodString, z.ZodNumber]>>;
        content: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        encoding: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"string">, z.ZodLiteral<"base64">]>>;
        owner: z.ZodString;
        repo: z.ZodString;
        path: z.ZodString;
        sha: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }, {
        owner: string;
        path: string;
        sha: string;
        repo: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }>, {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }, {
        owner: string;
        path: string;
        sha: string;
        repo: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    repositories: {
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        owner: string;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }[];
    organizations: {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[];
    users: {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }[];
    installations: {
        account: string;
        repository_selection: "all" | "selected";
        app_id: number;
        client_id: string;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        events: any[];
        updated_at: string;
        created_at: string;
        single_file_name: string;
        has_multiple_single_files: boolean;
        single_file_paths: string[];
        app_slug: string;
        suspended_at: string | null;
        suspended_by: string | null;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
    }[];
    branches: {
        name: string;
        commit: {
            url?: string | undefined;
            sha?: string | undefined;
        };
        protected: boolean;
        protection_url: string;
        protection?: any;
    }[];
    blobs: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }[];
}, {
    repositories: {
        name: string;
        owner: string;
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        description?: string | undefined;
        visibility?: "public" | "private" | undefined;
        forks?: number | undefined;
        watchers?: number | undefined;
        stargazers?: number | undefined;
        size?: number | undefined;
        html_url?: string | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        full_name?: string | undefined;
        pushed_at?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
        language?: string | null | undefined;
        default_branch?: string | undefined;
        private?: boolean | undefined;
        license?: Record<string, string> | null | undefined;
        fork?: boolean | undefined;
        topics?: string[] | undefined;
        is_template?: boolean | undefined;
        has_issues?: boolean | undefined;
        has_projects?: boolean | undefined;
        has_wiki?: boolean | undefined;
        has_pages?: boolean | undefined;
        has_downloads?: boolean | undefined;
        has_discussions?: boolean | undefined;
        archived?: boolean | undefined;
        disabled?: boolean | undefined;
        forks_count?: number | undefined;
        stargazers_count?: number | undefined;
        watchers_count?: number | undefined;
        open_issues_count?: number | undefined;
        open_issues?: number | undefined;
        security_and_analysis?: {
            advanced_security?: {
                status: string;
            } | undefined;
            secret_scanning?: {
                status: string;
            } | undefined;
            secret_scanning_push_protection?: {
                status: string;
            } | undefined;
            secret_scanning_non_provider_patterns?: {
                status: string;
            } | undefined;
        } | undefined;
    }[];
    organizations: {
        login: string;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        type?: "Organization" | "User" | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        avatar_url?: string | undefined;
        gravatar_id?: string | undefined;
        site_admin?: boolean | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[];
    users: {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }[];
    branches: {
        name?: string | undefined;
        commit?: {
            url?: string | undefined;
            sha?: string | undefined;
        } | undefined;
        protected?: boolean | undefined;
        protection?: any;
        protection_url?: string | undefined;
    }[];
    blobs: {
        owner: string;
        path: string;
        sha: string;
        repo: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }[];
    installations?: {
        account: string;
        id?: number | undefined;
        repository_selection?: "all" | "selected" | undefined;
        app_id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        client_id?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        events?: any[] | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        single_file_name?: string | undefined;
        has_multiple_single_files?: boolean | undefined;
        single_file_paths?: string[] | undefined;
        app_slug?: string | undefined;
        suspended_at?: string | null | undefined;
        suspended_by?: string | null | undefined;
    }[] | undefined;
}>, {
    repositories: {
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        owner: string;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }[];
    organizations: {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[];
    users: {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }[];
    installations: {
        account: string;
        repository_selection: "all" | "selected";
        app_id: number;
        client_id: string;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        events: any[];
        updated_at: string;
        created_at: string;
        single_file_name: string;
        has_multiple_single_files: boolean;
        single_file_paths: string[];
        app_slug: string;
        suspended_at: string | null;
        suspended_by: string | null;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
    }[];
    branches: {
        name: string;
        commit: {
            url?: string | undefined;
            sha?: string | undefined;
        };
        protected: boolean;
        protection_url: string;
        protection?: any;
    }[];
    blobs: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }[];
}, {
    repositories: {
        name: string;
        owner: string;
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        description?: string | undefined;
        visibility?: "public" | "private" | undefined;
        forks?: number | undefined;
        watchers?: number | undefined;
        stargazers?: number | undefined;
        size?: number | undefined;
        html_url?: string | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        full_name?: string | undefined;
        pushed_at?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
        language?: string | null | undefined;
        default_branch?: string | undefined;
        private?: boolean | undefined;
        license?: Record<string, string> | null | undefined;
        fork?: boolean | undefined;
        topics?: string[] | undefined;
        is_template?: boolean | undefined;
        has_issues?: boolean | undefined;
        has_projects?: boolean | undefined;
        has_wiki?: boolean | undefined;
        has_pages?: boolean | undefined;
        has_downloads?: boolean | undefined;
        has_discussions?: boolean | undefined;
        archived?: boolean | undefined;
        disabled?: boolean | undefined;
        forks_count?: number | undefined;
        stargazers_count?: number | undefined;
        watchers_count?: number | undefined;
        open_issues_count?: number | undefined;
        open_issues?: number | undefined;
        security_and_analysis?: {
            advanced_security?: {
                status: string;
            } | undefined;
            secret_scanning?: {
                status: string;
            } | undefined;
            secret_scanning_push_protection?: {
                status: string;
            } | undefined;
            secret_scanning_non_provider_patterns?: {
                status: string;
            } | undefined;
        } | undefined;
    }[];
    organizations: {
        login: string;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        type?: "Organization" | "User" | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        avatar_url?: string | undefined;
        gravatar_id?: string | undefined;
        site_admin?: boolean | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[];
    users: {
        login: string;
        organizations: string[];
        id?: string | number | undefined;
        email?: string | undefined;
        name?: string | undefined;
    }[];
    branches: {
        name?: string | undefined;
        commit?: {
            url?: string | undefined;
            sha?: string | undefined;
        } | undefined;
        protected?: boolean | undefined;
        protection?: any;
        protection_url?: string | undefined;
    }[];
    blobs: {
        owner: string;
        path: string;
        sha: string;
        repo: string;
        id?: string | number | undefined;
        content?: string | undefined;
        encoding?: "string" | "base64" | undefined;
    }[];
    installations?: {
        account: string;
        id?: number | undefined;
        repository_selection?: "all" | "selected" | undefined;
        app_id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        client_id?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
        permissions?: {
            push?: boolean | undefined;
            admin?: boolean | undefined;
            pull?: boolean | undefined;
        } | undefined;
        events?: any[] | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        single_file_name?: string | undefined;
        has_multiple_single_files?: boolean | undefined;
        single_file_paths?: string[] | undefined;
        app_slug?: string | undefined;
        suspended_at?: string | null | undefined;
        suspended_by?: string | null | undefined;
    }[] | undefined;
}>;
export type GitHubStore = z.output<typeof gitubInitialStoreSchema>;
export type GitHubInitialStore = z.input<typeof gitubInitialStoreSchema>;
export declare const convertToObj: <T extends {
    [k: string]: any;
}>(arrayOfObjects: T[], key?: IdProp) => Record<IdProp, T>;
export declare const convertInitialStateToStoreState: (initialState: GitHubStore | undefined) => {
    users: Record<IdProp, {
        login: string;
        id: string | number;
        organizations: string[];
        email?: string | undefined;
        name?: string | undefined;
    }>;
    installations: Record<IdProp, {
        account: string;
        repository_selection: "all" | "selected";
        app_id: number;
        client_id: string;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        events: any[];
        updated_at: string;
        created_at: string;
        single_file_name: string;
        has_multiple_single_files: boolean;
        single_file_paths: string[];
        app_slug: string;
        suspended_at: string | null;
        suspended_by: string | null;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
    }>;
    repositories: Record<IdProp, {
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        owner: string;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }>;
    branches: Record<IdProp, {
        name: string;
        commit: {
            url?: string | undefined;
            sha?: string | undefined;
        };
        protected: boolean;
        protection_url: string;
        protection?: any;
    }>;
    organizations: Record<IdProp, {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }>;
    blobs: Record<IdProp, {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }>;
} | undefined;
//# sourceMappingURL=entities.d.ts.map