import type { SimulationStore, ExtendSimulationActions, ExtendSimulationSelectors, ExtendSimulationSchema, TableOutput, AnyState } from "@simulacrum/foundation-simulator";
import { type GitHubStore, type GitHubBlob, type GitHubOrganization, type GitHubRepository, type GitHubUser, type GitHubBranch, GitHubAppInstallation } from "./entities";
import type { ExtendSimulationSchemaInput } from "@simulacrum/foundation-simulator/src/store/schema";
import type { ExtendSimulationActionsInput, ExtendSimulationSelectorsInput } from "@simulacrum/foundation-simulator/src/store";
export type ExtendedSchema = ({ slice }: ExtendSimulationSchema) => {
    users: (n: string) => TableOutput<GitHubUser, AnyState, GitHubUser | undefined>;
    installations: (n: string) => TableOutput<GitHubAppInstallation, AnyState, GitHubAppInstallation | undefined>;
    repositories: (n: string) => TableOutput<GitHubRepository, AnyState, GitHubRepository | undefined>;
    branches: (n: string) => TableOutput<GitHubBranch, AnyState, GitHubBranch | undefined>;
    organizations: (n: string) => TableOutput<GitHubOrganization, AnyState, GitHubOrganization | undefined>;
    blobs: (n: string) => TableOutput<GitHubBlob, AnyState, GitHubBlob | undefined>;
};
type ExtendActions = typeof inputActions;
type ExtendSelectors = typeof inputSelectors;
export type ExtendedSimulationStore = SimulationStore<ReturnType<ExtendedSchema>, ReturnType<ExtendActions>, ReturnType<ExtendSelectors>>;
declare const inputActions: (args: ExtendSimulationActions<ExtendedSchema>) => {};
declare const inputSelectors: (args: ExtendSimulationSelectors<ExtendedSchema>) => {
    allGithubOrganizations: ((state: AnyState) => {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[]) & import("reselect").OutputSelectorFields<(args_0: {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[]) => {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[], {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
    getAppInstallation: ((state: AnyState, org: string) => {
        account: {
            login?: string | undefined;
            type?: "Organization" | "User" | undefined;
            avatar_url?: string | undefined;
            gravatar_id?: string | undefined;
            site_admin?: boolean | undefined;
            url?: string | undefined;
            id?: number | undefined;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            html_url?: string | undefined;
            created_at?: string | undefined;
            node_id?: string | undefined;
            events_url?: string | undefined;
            followers_url?: string | undefined;
            following_url?: string | undefined;
            gists_url?: string | undefined;
            starred_url?: string | undefined;
            subscriptions_url?: string | undefined;
            organizations_url?: string | undefined;
            repos_url?: string | undefined;
            received_events_url?: string | undefined;
        };
        target_id: number | undefined;
        target_type: "Organization" | "User" | undefined;
        repository_selection?: "all" | "selected" | undefined;
        app_id?: number | undefined;
        client_id?: string | undefined;
        permissions?: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        } | undefined;
        events?: any[] | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        single_file_name?: string | undefined;
        has_multiple_single_files?: boolean | undefined;
        single_file_paths?: string[] | undefined;
        app_slug?: string | undefined;
        suspended_at?: string | null | undefined;
        suspended_by?: string | null | undefined;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
    }) & import("reselect").OutputSelectorFields<(args_0: {
        account: string;
        repository_selection: "all" | "selected";
        app_id: number;
        client_id: string;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        events: any[];
        updated_at: string;
        created_at: string;
        single_file_name: string;
        has_multiple_single_files: boolean;
        single_file_paths: string[];
        app_slug: string;
        suspended_at: string | null;
        suspended_by: string | null;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
        target_id?: number | undefined;
        target_type?: "Organization" | "User" | undefined;
    }[], args_1: {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }[], args_2: string) => {
        account: {
            login?: string | undefined;
            type?: "Organization" | "User" | undefined;
            avatar_url?: string | undefined;
            gravatar_id?: string | undefined;
            site_admin?: boolean | undefined;
            url?: string | undefined;
            id?: number | undefined;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            html_url?: string | undefined;
            created_at?: string | undefined;
            node_id?: string | undefined;
            events_url?: string | undefined;
            followers_url?: string | undefined;
            following_url?: string | undefined;
            gists_url?: string | undefined;
            starred_url?: string | undefined;
            subscriptions_url?: string | undefined;
            organizations_url?: string | undefined;
            repos_url?: string | undefined;
            received_events_url?: string | undefined;
        };
        target_id: number | undefined;
        target_type: "Organization" | "User" | undefined;
        repository_selection?: "all" | "selected" | undefined;
        app_id?: number | undefined;
        client_id?: string | undefined;
        permissions?: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        } | undefined;
        events?: any[] | undefined;
        updated_at?: string | undefined;
        created_at?: string | undefined;
        single_file_name?: string | undefined;
        has_multiple_single_files?: boolean | undefined;
        single_file_paths?: string[] | undefined;
        app_slug?: string | undefined;
        suspended_at?: string | null | undefined;
        suspended_by?: string | null | undefined;
        id?: number | undefined;
        access_tokens_url?: string | undefined;
        repositories_url?: string | undefined;
        html_url?: string | undefined;
    }, {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
    allReposWithOrgs: ((state: AnyState) => {
        owner: {
            login: string;
            type: "Organization" | "User";
            avatar_url: string;
            gravatar_id: string;
            site_admin: boolean;
            url?: string | undefined;
            id?: number | undefined;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            html_url?: string | undefined;
            created_at?: string | undefined;
            node_id?: string | undefined;
            events_url?: string | undefined;
            followers_url?: string | undefined;
            following_url?: string | undefined;
            gists_url?: string | undefined;
            starred_url?: string | undefined;
            subscriptions_url?: string | undefined;
            organizations_url?: string | undefined;
            repos_url?: string | undefined;
            received_events_url?: string | undefined;
        };
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }[]) & import("reselect").OutputSelectorFields<(args_0: {
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        owner: string;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }[], args_1: Record<import("@simulacrum/foundation-simulator").IdProp, {
        login: string;
        type: "Organization" | "User";
        avatar_url: string;
        gravatar_id: string;
        site_admin: boolean;
        url?: string | undefined;
        id?: number | undefined;
        email?: string | undefined;
        name?: string | undefined;
        description?: string | undefined;
        teams?: string[] | undefined;
        html_url?: string | undefined;
        created_at?: string | undefined;
        node_id?: string | undefined;
        events_url?: string | undefined;
        followers_url?: string | undefined;
        following_url?: string | undefined;
        gists_url?: string | undefined;
        starred_url?: string | undefined;
        subscriptions_url?: string | undefined;
        organizations_url?: string | undefined;
        repos_url?: string | undefined;
        received_events_url?: string | undefined;
    }>) => {
        owner: {
            login: string;
            type: "Organization" | "User";
            avatar_url: string;
            gravatar_id: string;
            site_admin: boolean;
            url?: string | undefined;
            id?: number | undefined;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            html_url?: string | undefined;
            created_at?: string | undefined;
            node_id?: string | undefined;
            events_url?: string | undefined;
            followers_url?: string | undefined;
            following_url?: string | undefined;
            gists_url?: string | undefined;
            starred_url?: string | undefined;
            subscriptions_url?: string | undefined;
            organizations_url?: string | undefined;
            repos_url?: string | undefined;
            received_events_url?: string | undefined;
        };
        name: string;
        description: string;
        visibility: "public" | "private";
        forks: number;
        watchers: number;
        stargazers: number;
        size: number;
        permissions: {
            push: boolean;
            admin: boolean;
            pull: boolean;
        };
        updated_at: string;
        created_at: string;
        full_name: string;
        pushed_at: string;
        language: string | null;
        default_branch: string;
        private: boolean;
        license: Record<string, string> | null;
        fork: boolean;
        topics: string[];
        is_template: boolean;
        has_issues: boolean;
        has_projects: boolean;
        has_wiki: boolean;
        has_pages: boolean;
        has_downloads: boolean;
        has_discussions: boolean;
        archived: boolean;
        disabled: boolean;
        forks_count: number;
        stargazers_count: number;
        watchers_count: number;
        open_issues_count: number;
        open_issues: number;
        security_and_analysis: {
            advanced_security: {
                status: string;
            };
            secret_scanning: {
                status: string;
            };
            secret_scanning_push_protection: {
                status: string;
            };
            secret_scanning_non_provider_patterns: {
                status: string;
            };
        };
        url?: string | undefined;
        id?: number | undefined;
        packages?: string[] | undefined;
        html_url?: string | undefined;
        node_id?: string | undefined;
        archive_url?: string | undefined;
        assignees_url?: string | undefined;
        blobs_url?: string | undefined;
        branches_url?: string | undefined;
        collaborators_url?: string | undefined;
        comments_url?: string | undefined;
        commits_url?: string | undefined;
        compare_url?: string | undefined;
        contents_url?: string | undefined;
        contributors_url?: string | undefined;
        deployments_url?: string | undefined;
        downloads_url?: string | undefined;
        events_url?: string | undefined;
        forks_url?: string | undefined;
        git_commits_url?: string | undefined;
        git_refs_url?: string | undefined;
        git_tags_url?: string | undefined;
        git_url?: string | undefined;
        issue_comment_url?: string | undefined;
        issue_events_url?: string | undefined;
        issues_url?: string | undefined;
        keys_url?: string | undefined;
        labels_url?: string | undefined;
        languages_url?: string | undefined;
        merges_url?: string | undefined;
        milestones_url?: string | undefined;
        notifications_url?: string | undefined;
        pulls_url?: string | undefined;
        releases_url?: string | undefined;
        ssh_url?: string | undefined;
        stargazers_url?: string | undefined;
        statuses_url?: string | undefined;
        subscribers_url?: string | undefined;
        subscription_url?: string | undefined;
        tags_url?: string | undefined;
        teams_url?: string | undefined;
        trees_url?: string | undefined;
        clone_url?: string | undefined;
        mirror_url?: string | undefined;
        hooks_url?: string | undefined;
        svn_url?: string | undefined;
        homepage?: string | undefined;
    }[], {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
    getBlob: ((state: AnyState, owner: string, repo: string, sha_or_path: string) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    } | undefined) & import("reselect").OutputSelectorFields<(args_0: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }[], args_1: {
        owner: string;
        repo: string;
        sha_or_path: string;
    }) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    } | undefined, {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
    getBlobAtOwnerRepo: ((state: AnyState, owner: string, repo: string) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }[]) & import("reselect").OutputSelectorFields<(args_0: {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }[], args_1: {
        owner: string;
        repo: string;
    }) => {
        id: string | number;
        owner: string;
        path: string;
        content: string;
        sha: string;
        encoding: "string" | "base64";
        repo: string;
    }[], {
        clearCache: () => void;
    }> & {
        clearCache: () => void;
    };
};
export declare const extendStore: <T>(initialState: GitHubStore | undefined, extended: {
    actions: ExtendSimulationActionsInput<any, ExtendSimulationSchemaInput<T>>;
    selectors: ExtendSimulationSelectorsInput<any, ExtendSimulationSchemaInput<T>>;
    schema?: ExtendSimulationSchemaInput<T>;
} | undefined) => {
    actions: (args: ExtendSimulationActions<ExtendedSchema>) => any;
    selectors: (args: ExtendSimulationSelectors<ExtendedSchema>) => any;
    schema: ({ slice }: ExtendSimulationSchema) => {
        users: (n: string) => TableOutput<{
            login: string;
            id: string | number;
            organizations: string[];
            email?: string | undefined;
            name?: string | undefined;
        }, AnyState, {
            login: string;
            id: string | number;
            organizations: string[];
            email?: string | undefined;
            name?: string | undefined;
        } | undefined>;
        installations: (n: string) => TableOutput<{
            account: string;
            repository_selection: "all" | "selected";
            app_id: number;
            client_id: string;
            permissions: {
                push: boolean;
                admin: boolean;
                pull: boolean;
            };
            events: any[];
            updated_at: string;
            created_at: string;
            single_file_name: string;
            has_multiple_single_files: boolean;
            single_file_paths: string[];
            app_slug: string;
            suspended_at: string | null;
            suspended_by: string | null;
            id?: number | undefined;
            access_tokens_url?: string | undefined;
            repositories_url?: string | undefined;
            html_url?: string | undefined;
            target_id?: number | undefined;
            target_type?: "Organization" | "User" | undefined;
        }, AnyState, {
            account: string;
            repository_selection: "all" | "selected";
            app_id: number;
            client_id: string;
            permissions: {
                push: boolean;
                admin: boolean;
                pull: boolean;
            };
            events: any[];
            updated_at: string;
            created_at: string;
            single_file_name: string;
            has_multiple_single_files: boolean;
            single_file_paths: string[];
            app_slug: string;
            suspended_at: string | null;
            suspended_by: string | null;
            id?: number | undefined;
            access_tokens_url?: string | undefined;
            repositories_url?: string | undefined;
            html_url?: string | undefined;
            target_id?: number | undefined;
            target_type?: "Organization" | "User" | undefined;
        } | undefined>;
        repositories: (n: string) => TableOutput<{
            name: string;
            description: string;
            visibility: "public" | "private";
            forks: number;
            owner: string;
            watchers: number;
            stargazers: number;
            size: number;
            permissions: {
                push: boolean;
                admin: boolean;
                pull: boolean;
            };
            updated_at: string;
            created_at: string;
            full_name: string;
            pushed_at: string;
            language: string | null;
            default_branch: string;
            private: boolean;
            license: Record<string, string> | null;
            fork: boolean;
            topics: string[];
            is_template: boolean;
            has_issues: boolean;
            has_projects: boolean;
            has_wiki: boolean;
            has_pages: boolean;
            has_downloads: boolean;
            has_discussions: boolean;
            archived: boolean;
            disabled: boolean;
            forks_count: number;
            stargazers_count: number;
            watchers_count: number;
            open_issues_count: number;
            open_issues: number;
            security_and_analysis: {
                advanced_security: {
                    status: string;
                };
                secret_scanning: {
                    status: string;
                };
                secret_scanning_push_protection: {
                    status: string;
                };
                secret_scanning_non_provider_patterns: {
                    status: string;
                };
            };
            url?: string | undefined;
            id?: number | undefined;
            packages?: string[] | undefined;
            html_url?: string | undefined;
            node_id?: string | undefined;
            archive_url?: string | undefined;
            assignees_url?: string | undefined;
            blobs_url?: string | undefined;
            branches_url?: string | undefined;
            collaborators_url?: string | undefined;
            comments_url?: string | undefined;
            commits_url?: string | undefined;
            compare_url?: string | undefined;
            contents_url?: string | undefined;
            contributors_url?: string | undefined;
            deployments_url?: string | undefined;
            downloads_url?: string | undefined;
            events_url?: string | undefined;
            forks_url?: string | undefined;
            git_commits_url?: string | undefined;
            git_refs_url?: string | undefined;
            git_tags_url?: string | undefined;
            git_url?: string | undefined;
            issue_comment_url?: string | undefined;
            issue_events_url?: string | undefined;
            issues_url?: string | undefined;
            keys_url?: string | undefined;
            labels_url?: string | undefined;
            languages_url?: string | undefined;
            merges_url?: string | undefined;
            milestones_url?: string | undefined;
            notifications_url?: string | undefined;
            pulls_url?: string | undefined;
            releases_url?: string | undefined;
            ssh_url?: string | undefined;
            stargazers_url?: string | undefined;
            statuses_url?: string | undefined;
            subscribers_url?: string | undefined;
            subscription_url?: string | undefined;
            tags_url?: string | undefined;
            teams_url?: string | undefined;
            trees_url?: string | undefined;
            clone_url?: string | undefined;
            mirror_url?: string | undefined;
            hooks_url?: string | undefined;
            svn_url?: string | undefined;
            homepage?: string | undefined;
        }, AnyState, {
            name: string;
            description: string;
            visibility: "public" | "private";
            forks: number;
            owner: string;
            watchers: number;
            stargazers: number;
            size: number;
            permissions: {
                push: boolean;
                admin: boolean;
                pull: boolean;
            };
            updated_at: string;
            created_at: string;
            full_name: string;
            pushed_at: string;
            language: string | null;
            default_branch: string;
            private: boolean;
            license: Record<string, string> | null;
            fork: boolean;
            topics: string[];
            is_template: boolean;
            has_issues: boolean;
            has_projects: boolean;
            has_wiki: boolean;
            has_pages: boolean;
            has_downloads: boolean;
            has_discussions: boolean;
            archived: boolean;
            disabled: boolean;
            forks_count: number;
            stargazers_count: number;
            watchers_count: number;
            open_issues_count: number;
            open_issues: number;
            security_and_analysis: {
                advanced_security: {
                    status: string;
                };
                secret_scanning: {
                    status: string;
                };
                secret_scanning_push_protection: {
                    status: string;
                };
                secret_scanning_non_provider_patterns: {
                    status: string;
                };
            };
            url?: string | undefined;
            id?: number | undefined;
            packages?: string[] | undefined;
            html_url?: string | undefined;
            node_id?: string | undefined;
            archive_url?: string | undefined;
            assignees_url?: string | undefined;
            blobs_url?: string | undefined;
            branches_url?: string | undefined;
            collaborators_url?: string | undefined;
            comments_url?: string | undefined;
            commits_url?: string | undefined;
            compare_url?: string | undefined;
            contents_url?: string | undefined;
            contributors_url?: string | undefined;
            deployments_url?: string | undefined;
            downloads_url?: string | undefined;
            events_url?: string | undefined;
            forks_url?: string | undefined;
            git_commits_url?: string | undefined;
            git_refs_url?: string | undefined;
            git_tags_url?: string | undefined;
            git_url?: string | undefined;
            issue_comment_url?: string | undefined;
            issue_events_url?: string | undefined;
            issues_url?: string | undefined;
            keys_url?: string | undefined;
            labels_url?: string | undefined;
            languages_url?: string | undefined;
            merges_url?: string | undefined;
            milestones_url?: string | undefined;
            notifications_url?: string | undefined;
            pulls_url?: string | undefined;
            releases_url?: string | undefined;
            ssh_url?: string | undefined;
            stargazers_url?: string | undefined;
            statuses_url?: string | undefined;
            subscribers_url?: string | undefined;
            subscription_url?: string | undefined;
            tags_url?: string | undefined;
            teams_url?: string | undefined;
            trees_url?: string | undefined;
            clone_url?: string | undefined;
            mirror_url?: string | undefined;
            hooks_url?: string | undefined;
            svn_url?: string | undefined;
            homepage?: string | undefined;
        } | undefined>;
        branches: (n: string) => TableOutput<{
            name: string;
            commit: {
                url?: string | undefined;
                sha?: string | undefined;
            };
            protected: boolean;
            protection_url: string;
            protection?: any;
        }, AnyState, {
            name: string;
            commit: {
                url?: string | undefined;
                sha?: string | undefined;
            };
            protected: boolean;
            protection_url: string;
            protection?: any;
        } | undefined>;
        organizations: (n: string) => TableOutput<{
            login: string;
            type: "Organization" | "User";
            avatar_url: string;
            gravatar_id: string;
            site_admin: boolean;
            url?: string | undefined;
            id?: number | undefined;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            html_url?: string | undefined;
            created_at?: string | undefined;
            node_id?: string | undefined;
            events_url?: string | undefined;
            followers_url?: string | undefined;
            following_url?: string | undefined;
            gists_url?: string | undefined;
            starred_url?: string | undefined;
            subscriptions_url?: string | undefined;
            organizations_url?: string | undefined;
            repos_url?: string | undefined;
            received_events_url?: string | undefined;
        }, AnyState, {
            login: string;
            type: "Organization" | "User";
            avatar_url: string;
            gravatar_id: string;
            site_admin: boolean;
            url?: string | undefined;
            id?: number | undefined;
            email?: string | undefined;
            name?: string | undefined;
            description?: string | undefined;
            teams?: string[] | undefined;
            html_url?: string | undefined;
            created_at?: string | undefined;
            node_id?: string | undefined;
            events_url?: string | undefined;
            followers_url?: string | undefined;
            following_url?: string | undefined;
            gists_url?: string | undefined;
            starred_url?: string | undefined;
            subscriptions_url?: string | undefined;
            organizations_url?: string | undefined;
            repos_url?: string | undefined;
            received_events_url?: string | undefined;
        } | undefined>;
        blobs: (n: string) => TableOutput<{
            id: string | number;
            owner: string;
            path: string;
            content: string;
            sha: string;
            encoding: "string" | "base64";
            repo: string;
        }, AnyState, {
            id: string | number;
            owner: string;
            path: string;
            content: string;
            sha: string;
            encoding: "string" | "base64";
            repo: string;
        } | undefined>;
    };
};
export {};
//# sourceMappingURL=index.d.ts.map